@@ -9,13 +9,15 @@ LOCAL=NO
 USE_CARTON=0
 
 # オプションをハンドリング
-while getopts m:lh opt
+while getopts m:lch opt
 do
 	case $opt in
 	m )    MODE=$OPTARG
 	       ;;
 	l )    LOCAL=YES
 	       ;;
+	c )    USE_CARTON=1
+	       ;;
 	h )    echo '% ./start_server.sh [<option>]
 version 1.0
     	
@@ -37,13 +39,13 @@ fi
 
 if [ ${USE_CARTON} = '1' ]
 then
-	CARTON="carton exec"
+	CARTON="local/bin/carton exec"
 fi
 
 cd $ROOT
 if [ ${MODE} = 'production' ]
 then
-	$CARTON starman -I lib -l $HOST:$PORT --pid $PID $PSGI
+	$CARTON starman -I local/lib/perl5 -I lib -l $HOST:$PORT --pid $PID $PSGI
 else
-	$CARTON plackup -I lib -R lib,tmpl --host $HOST --port $PORT $PSGI
+	$CARTON plackup -I local/lib/perl5 -I lib -R lib,tmpl --host $HOST --port $PORT $PSGI
 fi
